import {
  Box,
  Code,
  Database,
  BarChart3,
  Settings,
  Terminal,
  Server,
  Cloud,
  Monitor,
  Smartphone,
  Mail,
  MessageSquare,
  Video,
  Music,
  Image,
  Film,
  Camera,
  Gamepad2,
  Book,
  Newspaper,
  ShoppingCart,
  CreditCard,
  DollarSign,
  Briefcase,
  Home,
  Building,
  GraduationCap,
  Plane,
  Car,
  Wrench,
  Hammer,
  Paintbrush,
  Palette,
  Lightbulb,
  Flame,
  Zap,
  Moon,
  Sun,
  Star,
  Heart,
  Flag,
  Bell,
  Bookmark,
  Folder,
  File,
  FileCode,
  Clipboard,
  Calculator,
  Globe,
  Lock,
  Key,
  Shield,
  Users,
  Wifi,
  Cpu,
  HardDrive,
  Phone,
  Rocket,
  Search,
  Eye,
  Clock,
  MapPin,
  Package,
  Archive,
  Layers,
  Layout,
  Activity,
  AlertCircle,
  Compass,
  Radio,
  Truck,
  Printer,
} from "lucide-react";
import type { LucideIcon } from "lucide-react";

export const LUCIDE_ICONS: Record<string, LucideIcon> = {
  Box,
  Code,
  Database,
  BarChart3,
  Settings,
  Terminal,
  Server,
  Cloud,
  Monitor,
  Smartphone,
  Mail,
  MessageSquare,
  Video,
  Music,
  Image,
  Film,
  Camera,
  Gamepad2,
  Book,
  Newspaper,
  ShoppingCart,
  CreditCard,
  DollarSign,
  Briefcase,
  Home,
  Building,
  GraduationCap,
  Plane,
  Car,
  Wrench,
  Hammer,
  Paintbrush,
  Palette,
  Lightbulb,
  Flame,
  Zap,
  Moon,
  Sun,
  Star,
  Heart,
  Flag,
  Bell,
  Bookmark,
  Folder,
  File,
  FileCode,
  Clipboard,
  Calculator,
  Globe,
  Lock,
  Key,
  Shield,
  Users,
  Wifi,
  Cpu,
  HardDrive,
  Phone,
  Rocket,
  Search,
  Eye,
  Clock,
  MapPin,
  Package,
  Archive,
  Layers,
  Layout,
  Activity,
  AlertCircle,
  Compass,
  Radio,
  Truck,
  Printer,
};

export const LUCIDE_ICON_NAMES = Object.keys(LUCIDE_ICONS);
