import { NextResponse } from "next/server";
import { discoverAgents, toClientConfig } from "@/lib/agent-registry";

export async function GET() {
  const agents = await discoverAgents();
  return NextResponse.json({ agents: agents.map(toClientConfig) });
}
