import { NextResponse } from "next/server";
import { getHealth } from "@/lib/agent-client";

export async function GET() {
  try {
    const health = await getHealth();
    return NextResponse.json({ online: true, ...health });
  } catch {
    return NextResponse.json({ online: false }, { status: 200 });
  }
}
