"use client";

import { Menu } from "lucide-react";

interface MobileMenuToggleProps {
  onClick: () => void;
}

export function MobileMenuToggle({ onClick }: MobileMenuToggleProps) {
  return (
    <button
      onClick={onClick}
      className="flex h-11 w-11 items-center justify-center rounded-lg text-zinc-500 transition-colors hover:bg-zinc-100 hover:text-zinc-700 md:hidden dark:text-zinc-400 dark:hover:bg-zinc-800 dark:hover:text-zinc-200"
      title="Toggle menu"
    >
      <Menu size={20} />
    </button>
  );
}
