import { GitBranch } from "lucide-react";

export function GitView() {
  return (
    <div className="flex h-full flex-col items-center justify-center gap-3">
      <GitBranch size={32} className="text-zinc-300 dark:text-zinc-600" />
      <p className="text-sm text-zinc-400 dark:text-zinc-500">Coming Soon</p>
    </div>
  );
}
