import type { MenuCategory } from "./types";
import type { SubcategoryDef } from "./types";

export const DEFAULT_CATEGORIES: MenuCategory[] = [
  { id: "chat", label: "Chat", icon: "MessageSquare" },
  { id: "chronicle", label: "Chronicle", icon: "BookOpen" },
  { id: "calendar", label: "Calendar", icon: "Calendar" },
  { id: "agents", label: "Agents", icon: "Bot" },
  { id: "tools", label: "Tools", icon: "Wrench" },
  { id: "administration", label: "Administration", icon: "Shield" },
  { id: "apps", label: "Apps", icon: "LayoutGrid" },
  { id: "skills", label: "Skills", icon: "Sparkles" },
  { id: "music", label: "Music", icon: "Music" },
  { id: "status", label: "Status", icon: "Activity" },
];

export const STORAGE_KEYS = {
  THEME: "theme",
  SIDEBAR_ORDER: "sidebar-category-order",
  CHAT_CONVERSATION: "chat-conversation",
  ACTIVE_NAV: "active-nav",
} as const;

export const SUBCATEGORIES: Record<string, SubcategoryDef[]> = {
  calendar: [
    { id: "system", label: "System", icon: "Server" },
    { id: "family", label: "Family", icon: "Users" },
  ],
  skills: [
    { id: "agent-skills", label: "Agent Skills", icon: "BookOpen" },
    { id: "mcp", label: "MCP", icon: "Plug" },
  ],
  administration: [
    { id: "imessage", label: "iMessage", icon: "MessageCircle" },
    { id: "git", label: "Git", icon: "GitBranch" },
    { id: "backup", label: "Backup", icon: "HardDrive" },
    { id: "verification", label: "Verification", icon: "ShieldCheck" },
    { id: "tasks", label: "Tasks", icon: "ArrowRightLeft" },
    { id: "events", label: "Event Stream", icon: "Radio" },
  ],
  apps: [
    { id: "by-host", label: "By Host", icon: "Server" },
    { id: "by-type", label: "By Type", icon: "FolderOpen" },
  ],
};
