import { NextRequest } from "next/server";
import { proxyMutate } from "../../proxy";

export async function POST(req: NextRequest) { return proxyMutate("POST", "/playlists/import", await req.json()); }
