import { NextRequest } from "next/server";
import { proxyGet, proxyMutate } from "../proxy";

export async function GET() { return proxyGet("/queue"); }
export async function POST(req: NextRequest) { return proxyMutate("POST", "/queue", await req.json()); }
