"use client";

import { useContext } from "react";
import { ToolsMenuContext } from "@/components/providers/ToolsMenuProvider";

export function useToolsMenuContext() {
  return useContext(ToolsMenuContext);
}
