import { headers } from "next/headers";
import { NextResponse } from "next/server";

export async function GET() {
  const headersList = await headers();
  return NextResponse.json({
    email: headersList.get("x-forwarded-email") || "",
    name: headersList.get("x-forwarded-user") || "",
  });
}
